//
//  AppCoordinator.swift
//  iOSPOCs
//
//  Created by Roman Sorochak on 22.03.2022.
//

import SwiftUI
import SwiftUINavigation

final class AppCoordinator: Coordinator {

    // MARK: Route

    enum Route {
        case splash(viewModel: SplashViewModel)
        case signUp(coordinator: SignUpCoordinator)
        case verifyEmail(coordinator: VerifyEmailCoordinator)
        case home(coordinator: HomeCoordinator)
    }

    @Published var route: Route?

    // MARK: Life cycle

    init() {
        routeSplash()
    }

    // MARK: Private

    private func routeSplash() {
        let viewModel = SplashViewModel()
        viewModel.onResult = { [weak self] result in
            DispatchQueue.main.asyncAfter(deadline: .now() + 1) {
                switch result {
                case .userIsNotSignedIn:
                    self?.routeSignUp()
                case .userEmailIsNotVerified:
                    self?.routeEmailVerification()
                case .userIsSignedIn:
                    self?.routeHome()
                }
            }
        }
        withAnimation {
            route = .splash(viewModel: viewModel)
        }
    }

    private func routeSignUp() {
        let coordinator = SignUpCoordinator(onResult: { [weak self] result in
            switch result {
            case .userSignedUp, .userSignedIn:
                self?.routeSplash()
            }
        })
        withAnimation {
            route = .signUp(coordinator: coordinator)
        }
    }

    private func routeEmailVerification() {
        let coordinator = VerifyEmailCoordinator()
        coordinator.onResult = { [weak self] result in
            switch result {
            case .emailVerified, .emailAndPhoneVerified:
                self?.routeSplash()
            }
        }
        withAnimation {
            route = .verifyEmail(coordinator: coordinator)
        }
    }

    private func routeHome() {
        let coordinator = HomeCoordinator()
        coordinator.onResult = { [weak self] result in
            switch result {
            case .userLoggedOut:
                self?.routeSplash()
            }
        }
        withAnimation {
            route = .home(coordinator: coordinator)
        }
    }
}
