//
//  LoginView.swift
//  iOSPOCs
//
//  Created by Roman Sorochak on 23.03.2022.
//

import SwiftUI

struct LoginView: View {

    @ObservedObject var viewModel: LoginViewModel

    var body: some View {
        VStack(spacing: 15) {
            VStack(spacing: 15) {
                TextField("Email", text: $viewModel.email)
                    .disabled(viewModel.isLoading)
                    .textFieldStyle(RoundedBorderTextFieldStyle())
                    .accessibilityIdentifier("email")
                SecureField("Password", text: $viewModel.password)
                    .disabled(viewModel.isLoading)
                    .textFieldStyle(RoundedBorderTextFieldStyle())
                    .accessibilityIdentifier("password")
            }.padding()
            Button {
                viewModel.loginAction()
            } label: {
                if viewModel.isLoading {
                    ProgressView()
                        .progressViewStyle(CircularProgressViewStyle(tint: .white))
                } else {
                    Text("Login")
                }
            }
            .foregroundColor(.white)
            .font(Font.body.bold())
            .padding(10)
            .padding(.horizontal, 20)
            .background(Color.blue)
            .cornerRadius(10)
            .accessibilityIdentifier("login.login")

            Button {
                viewModel.signInWithAppleAction()
            } label: {
                if viewModel.isSignInWithAppleLoading {
                    ProgressView()
                        .progressViewStyle(CircularProgressViewStyle(tint: .white))
                } else {
                    Text("Sign In Apple")
                }
            }
            .foregroundColor(.white)
            .font(Font.body.bold())
            .padding(10)
            .padding(.horizontal, 20)
            .background(Color.blue)
            .cornerRadius(10)
        }
        .navigationTitle("Login")
        .alert(viewModel.error?.localizedDescription ?? "Error", isPresented: $viewModel.isErrorAlertShowing, actions: {
            Button("OK", role: .cancel) {}
        })
    }
}

#if DEBUG
struct AuthEmailView_Previews: PreviewProvider {
    static var previews: some View {
        LoginView(viewModel: LoginViewModel())
    }
}
#endif

