//
//  OTPView.swift
//  iOSPOCs
//
//  Created by Roman Sorochak on 21.03.2022.
//

import SwiftUI

struct OTPView: View {

    @ObservedObject var viewModel: OTPViewModel

    var body: some View {
        VStack(spacing: 15) {
            TextField("OTP", text: $viewModel.otpCode)
                .textFieldStyle(RoundedBorderTextFieldStyle())
                .padding()
                .accessibilityIdentifier("otp.otpField")
            Button {
                viewModel.continueAction()
            } label: {
                if viewModel.isLoading {
                    ProgressView()
                        .progressViewStyle(CircularProgressViewStyle(tint: .white))
                } else {
                    Text("Submit")
                }
            }
            .foregroundColor(.white)
            .font(Font.body.bold())
            .padding(10)
            .padding(.horizontal, 20)
            .background(Color.blue)
            .cornerRadius(10)
            .accessibilityIdentifier("otp.submitOTPButton")
        }
        .navigationTitle("Verify OTP")
        .alert(viewModel.error?.localizedDescription ?? "Error", isPresented: $viewModel.isErrorAlertShowing, actions: {
            Button("OK", role: .cancel) {}
        })
    }
}

#if DEBUG
struct OTPView_Previews: PreviewProvider {
    static var previews: some View {
        OTPView(viewModel: OTPViewModel(verificationId: "", phoneNumber: "", resolver: nil))
    }
}
#endif

