//
//  AuthPhoneNumberView.swift
//  iOSPOCs
//
//  Created by Roman Sorochak on 21.03.2022.
//

import SwiftUI

struct PhoneNumberView: View {

    @ObservedObject var viewModel: PhoneNumberViewModel

    var body: some View {
        VStack(spacing: 15) {
            VStack(spacing: 15) {
                TextField("Phone number", text: $viewModel.phoneNumberText)
                    .textFieldStyle(RoundedBorderTextFieldStyle())
                    .padding()
                    .accessibilityIdentifier("phoneNumber.phoneNumberField")
                Button {
                    viewModel.continueAction()
                } label: {
                    if viewModel.isLoading {
                        ProgressView()
                            .progressViewStyle(CircularProgressViewStyle(tint: .white))
                    } else {
                        Text("Send OTP Code")
                    }
                }
                .accessibilityIdentifier("phoneNumber.sendOTPButton")
                .foregroundColor(.white)
                .font(Font.body.bold())
                .padding(10)
                .padding(.horizontal, 20)
                .background(Color.blue)
                .cornerRadius(10)
            }
            if viewModel.isAbleToSkip {
                Button {
                    viewModel.skipAction()
                } label: {
                    Text("Skip")
                }
                .padding(40)
            }
        }
        .navigationTitle("Phone number")
        .navigationBarBackButtonHidden(true)
        .alert(viewModel.error?.localizedDescription ?? "Error", isPresented: $viewModel.isErrorAlertShowing, actions: {
            Button("OK", role: .cancel) { viewModel.okAlertAction() }
        })
    }
}

#if DEBUG
struct AuthPhoneNumberView_Previews: PreviewProvider {
    static var previews: some View {
        PhoneNumberView(viewModel: PhoneNumberViewModel(resolver: nil, hint: nil))
    }
}
#endif
