//
//  PhoneNumberCoordinator.swift
//  iOSPOCs
//
//  Created by Roman Sorochak on 24.03.2022.
//

import SwiftUI
import FirebaseAuth

// MARK: - PhoneNumberCoordinator

class PhoneNumberCoordinator: Coordinator, Resultable {

    // MARK: Result

    enum Result {
        case phoneNumberVerified
        case phoneNumberVerificationSkipped
    }

    var onResult: ((Result) -> Void)?

    // MARK: Route

    enum Route {
        case otp(viewModel: OTPViewModel)
        case loginRequired(coordinator: LoginCoordinator)
    }

    @Published var route: Route?

    // MARK: Properties

    let viewModel: PhoneNumberViewModel

    // MARK: Life cycle

    init(resolver: MultiFactorResolver?, hint: PhoneMultiFactorInfo?) {
        viewModel = PhoneNumberViewModel(resolver: resolver, hint: hint)
        viewModel.onResult = { [weak self] result in
            switch result {
            case .skipped:
                self?.onResult?(.phoneNumberVerificationSkipped)
            case .requireRecentLogin:
                self?.routeLogin()
            case let .optCodeDidSent(verificationId, phoneNumber, resolver):
                self?.routeOTP(verificationId: verificationId, phoneNumber: phoneNumber, resolver: resolver)
            }
        }
    }

    // MARK: Routes

    private func routeOTP(verificationId: String,
                          phoneNumber: String,
                          resolver: MultiFactorResolver?) {
        let viewModel = OTPViewModel(
            verificationId: verificationId,
            phoneNumber: phoneNumber,
            resolver: resolver
        )
        viewModel.onResult = { [weak self] result in
            switch result {
            case .otpVerified:
                self?.onResult?(.phoneNumberVerified)
            }
        }
        route = .otp(viewModel: viewModel)
    }

    private func routeLogin() {
        let coordinator = LoginCoordinator()
        coordinator.onResult = { [weak self] result in
            switch result {
            case .userSignedIn, .userSignedInEmailVerified, .userSignedInEmailAndPhoneVerified:
                self?.route = nil
            }
        }
        route = .loginRequired(coordinator: coordinator)
    }
}

