//
//  SignUpView.swift
//  iOSPOCs
//
//  Created by Roman Sorochak on 24.03.2022.
//

import SwiftUI

struct SignUpView: View {

    @ObservedObject var viewModel: SignUpViewModel

    var body: some View {
        VStack(spacing: 15) {
            VStack(spacing: 15) {
                TextField("Email", text: $viewModel.email)
                    .disabled(viewModel.isLoading)
                    .textFieldStyle(RoundedBorderTextFieldStyle())
                TextField("Password", text: $viewModel.password)
                    .disabled(viewModel.isLoading)
                    .textFieldStyle(RoundedBorderTextFieldStyle())
            }.padding()
            Button {
                viewModel.signUpAction()
            } label: {
                if viewModel.isLoading {
                    ProgressView()
                        .progressViewStyle(CircularProgressViewStyle(tint: .white))
                } else {
                    Text("SignUp")
                }
            }
            .foregroundColor(.white)
            .font(Font.body.bold())
            .padding(10)
            .padding(.horizontal, 20)
            .background(Color.blue)
            .cornerRadius(10)
            Button {
                viewModel.loginAction()
            } label: {
                Text("Login instead")
            }
            .padding(40)
            .accessibilityIdentifier("signup.login")
        }
        .navigationTitle("SignUp")
        .alert(viewModel.error?.localizedDescription ?? "Error", isPresented: $viewModel.isErrorAlertShowing, actions: {
            Button("OK", role: .cancel) {}
        })
    }
}

#if DEBUG
struct SignUpView_Previews: PreviewProvider {
    static var previews: some View {
        LoginView(viewModel: LoginViewModel())
    }
}
#endif


