//
//  SignUpViewModel.swift
//  iOSPOCs
//
//  Created by Roman Sorochak on 24.03.2022.
//

import SwiftUI
import FirebaseAuth

// MARK: - SignUpViewModel

class SignUpViewModel: ObservableObject, Resultable, Alertable {

    // MARK: Result

    enum Result: Equatable {
        case userIsSignedUp
        case userLoginAction
    }

    var onResult: ((Result) -> Void)?

    // MARK: Properties

    @Published var email: String = Environment.testEmail
    @Published var password: String = Environment.testPassword
    @Published var isLoading: Bool = false
    var error: Error? {
        didSet {
            isErrorAlertShowing = error != nil
        }
    }
    @Published var isErrorAlertShowing: Bool = false

    // MARK: Life cycle

    init() { }

    // MARK: Actions

    func signUpAction() {
        signUp()
    }

    func loginAction() {
        onResult?(.userLoginAction)
    }

    // MARK: Private

    private func signUp() {
        isLoading = true

        Auth.auth().createUser(withEmail: email, password: password) { [weak self] authDataResult, error in
            guard let self = self else { return }

            self.isLoading = false

            if let error = error {
                print(error)
                self.error = error
                return
            }

            self.onResult?(.userIsSignedUp)
        }
    }
}


