//
//  SignUpCoordinator.swift
//  iOSPOCs
//
//  Created by Roman Sorochak on 24.03.2022.
//

import SwiftUI
import SwiftUINavigation

// MARK: - SignUpCoordinator

class SignUpCoordinator: Coordinator, Resultable {

    // MARK: Result

    enum Result {
        case userSignedUp
        case userSignedIn
    }

    var onResult: ((Result) -> Void)?

    // MARK: Route

    enum Route {
        case verifyEmail(coordinator: VerifyEmailCoordinator)
        case login(coordinator: LoginCoordinator)
    }

    @Published var route: Route?

    // MARK: Properties

    let signUpViewModel: SignUpViewModel

    // MARK: Life cycle

    init(onResult: @escaping ((Result) -> Void)) {
        self.onResult = onResult

        signUpViewModel = SignUpViewModel()
        signUpViewModel.onResult = { [weak self] result in
            switch result {
            case .userIsSignedUp:
                self?.routeVerifyEmail()
            case .userLoginAction:
                self?.routeLogin()
            }
        }
    }

    // MARK: Routes

    private func routeVerifyEmail() {
        let coordinator = VerifyEmailCoordinator()
        coordinator.onResult = { [weak self] result in
            switch result {
            case .emailVerified, .emailAndPhoneVerified:
                self?.onResult?(.userSignedUp)
            }
        }
        route = .verifyEmail(coordinator: coordinator)
    }

    private func routeLogin() {
        let coordinator = LoginCoordinator()
        coordinator.onResult = { [weak self] result in
            switch result {
            case .userSignedIn, .userSignedInEmailVerified, .userSignedInEmailAndPhoneVerified:
                self?.route = nil
                self?.onResult?(.userSignedIn)
            }
        }
        route = .login(coordinator: coordinator)
    }
}
