//
//  VerifyEmailView.swift
//  iOSPOCs
//
//  Created by Roman Sorochak on 23.03.2022.
//

import SwiftUI

struct VerifyEmailView: View {

    @ObservedObject var viewModel: VerifyEmailViewModel

    var body: some View {
        VStack(spacing: 15) {
            Text("Verify your email by clicking on a magic link")
            if viewModel.emailSent {
                Text(viewModel.email)
            } else {
                Button {
                    viewModel.sendVerificationEmailAction()
                } label: {
                    if viewModel.isLoading {
                        ProgressView()
                            .progressViewStyle(CircularProgressViewStyle(tint: .white))
                    } else {
                        Text("Send Verification Email")
                    }
                }
                .foregroundColor(.white)
                .font(Font.body.bold())
                .padding(10)
                .padding(.horizontal, 20)
                .background(Color.blue)
                .cornerRadius(10)
            }
        }
        .navigationTitle("Verify Email")
        .navigationBarBackButtonHidden(true)
        .onAppear(perform: { viewModel.onAppear() })
        .onOpenURL(perform: { viewModel.onOpenURL($0) })
        .alert(viewModel.error?.localizedDescription ?? "Error", isPresented: $viewModel.isErrorAlertShowing, actions: {
            Button("OK", role: .cancel) {}
        })
    }
}

#if DEBUG
struct VerifyEmailView_Previews: PreviewProvider {
    static var previews: some View {
        VerifyEmailView(viewModel: VerifyEmailViewModel())
    }
}
#endif


