//
//  VerifyEmailCoordinator.swift
//  iOSPOCs
//
//  Created by Roman Sorochak on 24.03.2022.
//

import SwiftUI
import FirebaseAuth

// MARK: - VerifyEmailCoordinator

class VerifyEmailCoordinator: Coordinator, Resultable {

    // MARK: Result

    enum Result: Equatable {
        case emailVerified
        case emailAndPhoneVerified
    }

    var onResult: ((Result) -> Void)?

    // MARK: Route

    enum Route {
        case phoneNumber(coordinator: PhoneNumberCoordinator)
    }

    @Published var route: Route?

    // MARK: Properties

    let viewModel: VerifyEmailViewModel

    // MARK: Life cycle

    init() {
        viewModel = VerifyEmailViewModel()
        viewModel.onResult = { [weak self] result in
            switch result {
            case .emailVerified:
                self?.routePhoneNumber()
            }
        }
    }

    // MARK: Routes

    private func routePhoneNumber() {
        let coordinator = PhoneNumberCoordinator(resolver: nil, hint: nil)
        coordinator.onResult = { [weak self] result in
            switch result {
            case .phoneNumberVerified:
                self?.route = nil
                self?.onResult?(.emailAndPhoneVerified)
            case .phoneNumberVerificationSkipped:
                self?.route = nil
                self?.onResult?(.emailVerified)
            }
        }
        route = .phoneNumber(coordinator: coordinator)
    }
}
