//
//  ContentView.swift
//  iOSPOCs
//
//  Created by Roman Sorochak on 21.03.2022.
//

import SwiftUI

struct HomeView: View {

    @ObservedObject var viewModel: HomeViewModel

    var body: some View {
        VStack(spacing: 30) {
            ForEach(viewModel.secondFactors, id: \.self) { secondFactor in
                HStack {
                    Text(secondFactor.factorID)
                    Text(secondFactor.displayName ?? "")
                }
            }
            if viewModel.is2StepVerificationDisabled {
                Button {
                    viewModel.add2StepVerificationAction()
                } label: {
                    Text("Add 2 step verification")
                }
                .foregroundColor(.white)
                .font(Font.body.bold())
                .padding(10)
                .padding(.horizontal, 20)
                .background(Color.blue)
                .cornerRadius(10)
            } else {
                Button {
                    viewModel.removeMFA()
                } label: {
                    Text("Remove MFA")
                }

                Button {
                    viewModel.addBackPhoneNumberAction()
                } label: {
                    Text("Add backup Phone Number as MFA")
                }
                .foregroundColor(.white)
                .font(Font.body.bold())
                .padding(10)
                .padding(.horizontal, 20)
                .background(Color.blue)
                .cornerRadius(10)
            }

            Button {
                viewModel.logoutAction()
            } label: {
                Text("Log Out")
            }
            .foregroundColor(.white)
            .font(Font.body.bold())
            .padding(10)
            .padding(.horizontal, 20)
            .background(Color.blue)
            .cornerRadius(10)

            Button {
                viewModel.deleteAction()
            } label: {
                if viewModel.isLoadingDeleteUser {
                    ProgressView()
                        .progressViewStyle(CircularProgressViewStyle(tint: .white))
                } else {
                    Text("Delete user")
                }
            }
            .foregroundColor(.white)
            .font(Font.body.bold())
            .padding(10)
            .padding(.horizontal, 20)
            .background(Color.blue)
            .cornerRadius(10)
        }
        .navigationTitle("Home")
        .onAppear(perform: { viewModel.onAppear() })
        .alert(viewModel.error?.localizedDescription ?? "Error", isPresented: $viewModel.isErrorAlertShowing, actions: {
            Button("OK", role: .cancel) { }
        })
    }
}

struct HomeView_Previews: PreviewProvider {
    static var previews: some View {
        HomeView(viewModel: HomeViewModel())
    }
}
