//
//  HomeViewModel.swift
//  iOSPOCs
//
//  Created by Roman Sorochak on 22.03.2022.
//

import SwiftUI
import FirebaseAuth

class HomeViewModel: ObservableObject, Resultable, Alertable {

    // MARK: Result

    enum Result {
        case add2StepVerificationAction
        case addBackupPhoneNumber
        case userLoggedOut
        case userDeleted
    }

    var onResult: ((Result) -> Void)?

    // MARK: Properties

    var error: Error? {
        didSet {
            isErrorAlertShowing = error != nil
        }
    }
    @Published var isErrorAlertShowing: Bool = false
    @Published var isLoadingDeleteUser: Bool = false

    @Published var is2StepVerificationDisabled: Bool = false
    @Published var secondFactors: [PhoneMultiFactorInfo] = []

    // MARK: Life cycle

    func onAppear() {
        secondFactors = Auth.auth().currentUser?.multiFactor.enrolledFactors.compactMap({ multiFactorInfo in
            if let phoneMultiFactorInfo = multiFactorInfo as? PhoneMultiFactorInfo {
                return phoneMultiFactorInfo
            }
            return nil
        }) ?? []
        for secondFactor in Auth.auth().currentUser?.multiFactor.enrolledFactors ?? [] {
            if let phoneMultiFactorInfo = secondFactor as? PhoneMultiFactorInfo {
                print(phoneMultiFactorInfo.phoneNumber)
            } else {
                print("not a phone number")
                print(String(describing: secondFactor.self))
                print(secondFactor.enrollmentDate)
            }
        }
        let disabled = Auth.auth().currentUser?.multiFactor.enrolledFactors.isEmpty == true
        is2StepVerificationDisabled = disabled
    }

    // MARK: Actions

    func add2StepVerificationAction() {
        onResult?(.add2StepVerificationAction)
    }

    func addBackPhoneNumberAction() {
        onResult?(.addBackupPhoneNumber)
    }

    func removeMFA() {
        guard let factor = Auth.auth().currentUser?.multiFactor.enrolledFactors.first else { return }
        Auth.auth().currentUser?.multiFactor.unenroll(with: factor, completion: { error in
            if let error = error {
                print(error)
                self.error = error
            }
            Auth.auth().currentUser?.reload(completion: { [weak self] error in
                guard let self = self else { return }

                if let error = error {
                    print(error)
                    self.error = error
                    return
                }

                self.onAppear()
            })
        })
    }

    func logoutAction() {
        do {
            try Auth.auth().signOut()
            onResult?(.userLoggedOut)
        } catch {
            print(error)
            self.error = error
        }
    }

    func deleteAction() {
        isLoadingDeleteUser = true

        Auth.auth().currentUser?.delete(completion: { [weak self] error in
            self?.isLoadingDeleteUser = false

            if let error = error {
                print(error)
                self?.error = error
                return
            }
            self?.onResult?(.userDeleted)
        })
    }
}
