//
//  HomeCoordinator.swift
//  iOSPOCs
//
//  Created by Roman Sorochak on 24.03.2022.
//

import SwiftUI

// MARK: - HomeCoordinator

class HomeCoordinator: Coordinator, Resultable {

    // MARK: Result

    enum Result {
        case userLoggedOut
    }

    var onResult: ((Result) -> Void)?

    // MARK: Route

    enum Route {
        case add2StepVerification(coordinator: PhoneNumberCoordinator)
    }

    @Published var route: Route?

    // MARK: Properties

    let viewModel: HomeViewModel

    // MARK: Life cycle

    init() {
        viewModel = HomeViewModel()
        viewModel.onResult = { [weak self] result in
            switch result {
            case .add2StepVerificationAction:
                self?.routeAdd2StepVerification()
            case .userLoggedOut, .userDeleted:
                self?.onResult?(.userLoggedOut)
            case .addBackupPhoneNumber:
                self?.routeAdd2StepVerification()
            }
        }
    }

    // MARK: Routes

    private func routeAdd2StepVerification() {
        let coordinator = PhoneNumberCoordinator(resolver: nil, hint: nil)
        coordinator.onResult = { [weak self] result in
            switch result {
            case .phoneNumberVerified, .phoneNumberVerificationSkipped:
                self?.route = nil
            }
        }
        route = .add2StepVerification(coordinator: coordinator)
    }
}
