//
//  HomeCoordinatorView.swift
//  iOSPOCs
//
//  Created by Roman Sorochak on 24.03.2022.
//

import SwiftUI
import SwiftUINavigation

struct HomeCoordinatorView: View {

    @SwiftUI.Environment(\.scenePhase) var scenePhase
    @ObservedObject var coordinator: HomeCoordinator
    @State private var blurRadius: CGFloat = 0

    var body: some View {
        NavigationView {
            ZStack {
                HomeView(viewModel: coordinator.viewModel)

                NavigationLink(unwrapping: $coordinator.route, case: /HomeCoordinator.Route.add2StepVerification) { $coordinator in
                    PhoneNumberCoordinatorView(coordinator: coordinator)
                } onNavigate: { _ in } label: { }
                    .isDetailLink(false)
            }
        }
        .navigationViewStyle(.stack)
        .blur(radius: blurRadius)
        .onChange(of: scenePhase, perform: { value in
            switch value {
            case .active : withAnimation { blurRadius = 0 }
            case .inactive: withAnimation { blurRadius = 15 }
            case .background:
                blurRadius = 20
            @unknown default: print("Unknown")
            }
        })
    }
}
