//
//  LaunchViewModel.swift
//  iOSPOCs
//
//  Created by Roman Sorochak on 21.03.2022.
//

import SwiftUI
import Firebase
import FirebaseAuth

// MARK: - SplashViewModel

final class SplashViewModel: ObservableObject, Resultable {

    // MARK: Result

    enum Result: Equatable {
        case userIsNotSignedIn
        case userEmailIsNotVerified
        case userIsSignedIn
    }

    var onResult: ((Result) -> Void)?

    // MARK: Life cycle

    func onAppear() {
        guard let oldUser = Auth.auth().currentUser else {
            self.onResult?(.userIsNotSignedIn)
            return
        }

        oldUser.getIDTokenForcingRefresh(true, completion: { [weak self] idToken, error in
            guard let self = self else { return }

            Auth.auth().currentUser?.reload(completion: { error in
                guard let user = Auth.auth().currentUser else {
                    self.onResult?(.userIsNotSignedIn)
                    return
                }

                if let error = error {
                    print(error)
                    self.onResult?(.userIsNotSignedIn)
                    return
                }

                guard user.isEmailVerified else {
                    self.onResult?(.userEmailIsNotVerified)
                    return
                }

                self.onResult?(.userIsSignedIn)
            })
        })
    }
}
