//
//  AppCoordinatorTests.swift
//  iOSPOCsTests
//
//  Created by Roman Sorochak on 30.03.2022.
//

import XCTest
import SwiftUI
@testable import iOSPOCs

final class AppCoordinatorTests: XCTestCase {

    func test_init() {
        let sut = AppCoordinator()

        switch sut.route {
        case .splash:
            XCTAssert(true)
        default:
            XCTAssert(false)
        }
    }

    func test_routeSignUp() {
        let sut = AppCoordinator()

        switch sut.route {
        case .splash(let viewModel):
            viewModel.onResult?(.userIsNotSignedIn)

            switch sut.route {
            case .signUp:
                XCTAssert(true)
            default:
                XCTAssert(false)
            }

        default:
            XCTAssert(false)
        }
    }

    func test_routeSignUp_resultSignedUp() {
        let sut = AppCoordinator()

        switch sut.route {
        case .splash(let viewModel):
            viewModel.onResult?(.userIsNotSignedIn)

            switch sut.route {
            case .signUp(let coordinator):

                coordinator.onResult?(.userSignedUp)

                switch sut.route {
                case .splash:
                    XCTAssert(true)
                default:
                    XCTAssert(false)
                }
            default:
                XCTAssert(false)
            }
        default:
            XCTAssert(false)
        }
    }

    func test_routeSignUp_resultSignedIn() {
        let sut = AppCoordinator()

        switch sut.route {
        case .splash(let viewModel):
            viewModel.onResult?(.userIsNotSignedIn)

            switch sut.route {
            case .signUp(let coordinator):

                coordinator.onResult?(.userSignedIn)

                switch sut.route {
                case .splash:
                    XCTAssert(true)
                default:
                    XCTAssert(false)
                }
            default:
                XCTAssert(false)
            }
        default:
            XCTAssert(false)
        }
    }

    func test_routeEmailVerification() {
        let sut = AppCoordinator()

        switch sut.route {
        case .splash(let viewModel):
            viewModel.onResult?(.userEmailIsNotVerified)

            switch sut.route {
            case .verifyEmail:
                XCTAssert(true)
            default:
                XCTAssert(false)
            }

        default:
            XCTAssert(false)
        }
    }

    func test_routeEmailVerification_resultEmailVerified() {
        let sut = AppCoordinator()

        switch sut.route {
        case .splash(let viewModel):
            viewModel.onResult?(.userEmailIsNotVerified)

            switch sut.route {
            case .verifyEmail(let coordinator):

                coordinator.onResult?(.emailVerified)

                switch sut.route {
                case .splash:
                    XCTAssert(true)
                default:
                    XCTAssert(false)
                }
            default:
                XCTAssert(false)
            }
        default:
            XCTAssert(false)
        }
    }

    func test_routeEmailVerification_resultEmailAndPhoneVerified() {
        let sut = AppCoordinator()

        switch sut.route {
        case .splash(let viewModel):
            viewModel.onResult?(.userEmailIsNotVerified)

            switch sut.route {
            case .verifyEmail(let coordinator):

                coordinator.onResult?(.emailAndPhoneVerified)

                switch sut.route {
                case .splash:
                    XCTAssert(true)
                default:
                    XCTAssert(false)
                }
            default:
                XCTAssert(false)
            }
        default:
            XCTAssert(false)
        }
    }

    func test_routeHome() {
        let sut = AppCoordinator()

        switch sut.route {
        case .splash(let viewModel):
            viewModel.onResult?(.userIsSignedIn)

            switch sut.route {
            case .home:
                XCTAssert(true)
            default:
                XCTAssert(false)
            }

        default:
            XCTAssert(false)
        }
    }

    func test_routeHome_resultUserLoggedOut() {
        let sut = AppCoordinator()

        switch sut.route {
        case .splash(let viewModel):
            viewModel.onResult?(.userIsSignedIn)

            switch sut.route {
            case .home(let coordinator):

                coordinator.onResult?(.userLoggedOut)

                switch sut.route {
                case .splash:
                    XCTAssert(true)
                default:
                    XCTAssert(false)
                }
            default:
                XCTAssert(false)
            }
        default:
            XCTAssert(false)
        }
    }
}
