//
//  AppCoordinatorViewTests.swift
//  iOSPOCsTests
//
//  Created by Roman Sorochak on 30.03.2022.
//

import ViewInspector
import XCTest
import SwiftUI
@testable import iOSPOCs

extension AppCoordinatorView: Inspectable { }
extension SplashView: Inspectable { }
extension SignUpCoordinatorView: Inspectable { }
extension VerifyEmailCoordinatorView: Inspectable { }
extension HomeCoordinatorView: Inspectable { }
extension EmptyView: Inspectable { }

final class AppCoordinatorViewTests: XCTestCase {

    func test_routeSplash() throws {
        let coordinator = AppCoordinator()
        let sut = AppCoordinatorView(coordinator: coordinator)

        let currentView = try sut.inspect().view(SplashView.self)
        XCTAssertNotNil(currentView)
    }

    func test_routeSignUp() throws {
        let coordinator = AppCoordinator()
        let sut = AppCoordinatorView(coordinator: coordinator)

        coordinator.route = .signUp(coordinator: SignUpCoordinator(onResult: { _ in }))

        let currentView = try sut.inspect().view(SignUpCoordinatorView.self)
        XCTAssertNotNil(currentView)
    }

    func test_routeVerifyEmail() throws {
        let coordinator = AppCoordinator()
        let sut = AppCoordinatorView(coordinator: coordinator)

        coordinator.route = .verifyEmail(coordinator: VerifyEmailCoordinator())

        let currentView = try sut.inspect().view(VerifyEmailCoordinatorView.self)
        XCTAssertNotNil(currentView)
    }

    func test_routeHome() throws {
        let coordinator = AppCoordinator()
        let sut = AppCoordinatorView(coordinator: coordinator)

        coordinator.route = .home(coordinator: HomeCoordinator())

        let currentView = try sut.inspect().view(HomeCoordinatorView.self)
        XCTAssertNotNil(currentView)
    }

    func test_routeIsNil() throws {
        let coordinator = AppCoordinator()
        let sut = AppCoordinatorView(coordinator: coordinator)

        coordinator.route = nil

        let currentView = try sut.inspect().view(EmptyView.self)
        XCTAssertNotNil(currentView)
    }
}
