//
//  SignUpCoordinatorTests.swift
//  iOSPOCsTests
//
//  Created by Roman Sorochak on 30.03.2022.
//

import XCTest
import SwiftUI
@testable import iOSPOCs

final class SignUpCoordinatorTests: XCTestCase {

    func test_routeVerifyEmail() {
        let sut = SignUpCoordinator { _ in }

        XCTAssertNil(sut.route)

        sut.signUpViewModel.onResult?(.userIsSignedUp)

        switch sut.route {
        case .verifyEmail:
            XCTAssert(true)
        default:
            XCTAssert(false)
        }
    }

    func test_routeVerifyEmail_result_emailVerified() {
        let sut = SignUpCoordinator { result in
            switch result {
            case .userSignedUp:
                XCTAssert(true)
            default:
                XCTAssert(false)
            }
        }

        XCTAssertNil(sut.route)

        sut.signUpViewModel.onResult?(.userIsSignedUp)

        switch sut.route {
        case .verifyEmail(let coordinator):
            coordinator.onResult?(.emailVerified)
        default:
            XCTAssert(false)
        }
    }

    func test_routeVerifyEmail_result_emailAndPhoneVerified() {
        let sut = SignUpCoordinator { result in
            switch result {
            case .userSignedUp:
                XCTAssert(true)
            default:
                XCTAssert(false)
            }
        }

        XCTAssertNil(sut.route)

        sut.signUpViewModel.onResult?(.userIsSignedUp)

        switch sut.route {
        case .verifyEmail(let coordinator):
            coordinator.onResult?(.emailAndPhoneVerified)
        default:
            XCTAssert(false)
        }
    }

    func test_routeLogin() {
        let sut = SignUpCoordinator { _ in }

        XCTAssertNil(sut.route)

        sut.signUpViewModel.onResult?(.userLoginAction)

        switch sut.route {
        case .login:
            XCTAssert(true)
        default:
            XCTAssert(false)
        }
    }

    func test_routeLogin_result_userSignedIn() {
        let sut = SignUpCoordinator { result in
            switch result {
            case .userSignedIn:
                XCTAssert(true)
            default:
                XCTAssert(false)
            }
        }

        XCTAssertNil(sut.route)

        sut.signUpViewModel.onResult?(.userLoginAction)

        switch sut.route {
        case .login(let coordinator):
            coordinator.onResult?(.userSignedIn)
        default:
            XCTAssert(false)
        }
    }

    func test_routeLogin_result_userSignedInEmailVerified() {
        let sut = SignUpCoordinator { result in
            switch result {
            case .userSignedIn:
                XCTAssert(true)
            default:
                XCTAssert(false)
            }
        }

        XCTAssertNil(sut.route)

        sut.signUpViewModel.onResult?(.userLoginAction)

        switch sut.route {
        case .login(let coordinator):
            coordinator.onResult?(.userSignedInEmailVerified)
        default:
            XCTAssert(false)
        }
    }

    func test_routeLogin_result_userSignedInEmailAndPhoneVerified() {
        let sut = SignUpCoordinator { result in
            switch result {
            case .userSignedIn:
                XCTAssert(true)
            default:
                XCTAssert(false)
            }
        }

        XCTAssertNil(sut.route)

        sut.signUpViewModel.onResult?(.userLoginAction)

        switch sut.route {
        case .login(let coordinator):
            coordinator.onResult?(.userSignedInEmailAndPhoneVerified)
        default:
            XCTAssert(false)
        }
    }
}
