//
//  LoginFlowUITests.swift
//  iOSPOCsUITests
//
//  Created by Roman Sorochak on 01.04.2022.
//

import XCTest
import FirebaseAuth

final class LoginFlowUITests: XCTestCase {

    private let app = XCUIApplication()

    override func setUpWithError() throws {
        continueAfterFailure = false

        app.launchArguments.append("-logout")

        app.launch()
    }

    func testLoginFlow() {
        app.signUpNavigateLogin()

        XCTAssertTrue(app.staticTexts["Login"].waitForExistence(timeout: waitForExistanceTimeout))

        app.loginPerformLogin()

        XCTAssertTrue(app.staticTexts["Phone number"].waitForExistence(timeout: waitForExistanceTimeout))

        app.phoneNumberPerformSendOTP()

        XCTAssertTrue(app.staticTexts["Verify OTP"].waitForExistence(timeout: waitForExistanceTimeout))

        app.otpPerformSubmitOTP()

        XCTAssertTrue(app.staticTexts["Home"].waitForExistence(timeout: waitForExistanceTimeout))
    }
}

extension XCUIApplication {

    func signUpNavigateLogin() {
        buttons["signup.login"].tap()
    }

    func loginPerformLogin() {
        let emailField = textFields["email"]
        emailField.tap()
        emailField.typeText(Environment.testEmail)

        let passwordField = secureTextFields["password"]
        passwordField.tap()
        passwordField.typeText(Environment.testPassword)

        keyboards.buttons["Return"].tap()

        buttons["login.login"].tap()
    }

    func phoneNumberPerformSendOTP() {
        let phoneNumberField = textFields["phoneNumber.phoneNumberField"]
        phoneNumberField.tap()
        phoneNumberField.typeText(Environment.testPhoneNumber)

        keyboards.buttons["Return"].tap()

        buttons["phoneNumber.sendOTPButton"].tap()
    }

    func otpPerformSubmitOTP() {
        let otpField = textFields["otp.otpField"]
        otpField.tap()
        otpField.typeText(Environment.testOTP)

        keyboards.buttons["Return"].tap()

        buttons["otp.submitOTPButton"].tap()
    }
}
